:github_url: https://github.com/adimian/kirby

Welcome to Kirby documentation!
===============================

..  toctree::
    :maxdepth: 1
    :caption: Contents

    readme
    concepts
    features
    usage

..  toctree::
    :maxdepth: 1
    :caption: Package Reference

..  toctree::
    :maxdepth: 1
    :caption: Development

    contribute
    changelog

..  toctree::
    :maxdepth: 1
    :caption: Miscellaneous

    comparisons


Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
